Enumeration
WebKitInsecureContentEvent
Description [src]
Enum values previously used to denote the different events which can trigger the detection of insecure content. Since 2.46, WebKit generally no longer loads insecure content in secure contexts.
| Deprecated since: | 2.46 |
Please do not use it in newly written code. | |
Members
| Name | Description |
|---|---|
WEBKIT_INSECURE_CONTENT_RUN |
Insecure content has been detected by trying to execute any kind of logic (e.g. a script) from an untrusted source. |
WEBKIT_INSECURE_CONTENT_DISPLAYED |
Insecure content has been detected by trying to display any kind of resource (e.g. an image) from an untrusted source. |